"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const aws_sdk_1 = require("aws-sdk");
// polyfill Symbol.asyncIterator
if (Symbol["asyncIterator"] === undefined) {
    Symbol["asyncIterator"] = Symbol.for("asyncIterator");
}
class DynamoDBSubscriptionManager {
    constructor({ subscriptionsTableName = "Subscriptions" } = {}) {
        this.subscribersByEventName = (name) => {
            let ExclusiveStartKey;
            let done = false;
            return {
                next: async () => {
                    if (done) {
                        return { value: undefined, done: true };
                    }
                    const result = await this.db
                        .query({
                        ExclusiveStartKey,
                        TableName: this.tableName,
                        Limit: 50,
                        KeyConditionExpression: "event = :event",
                        ExpressionAttributeValues: {
                            ":event": name
                        }
                    })
                        .promise();
                    ExclusiveStartKey = result.LastEvaluatedKey;
                    if (ExclusiveStartKey == null) {
                        done = true;
                    }
                    // we store connectionData on subscription too so we don't
                    // need to load data from connections table
                    const value = result.Items;
                    return { value, done: value.length === 0 };
                },
                [Symbol.asyncIterator]() {
                    return this;
                }
            };
        };
        this.subscribe = async (names, connection, operation) => {
            await this.db
                .batchWrite({
                RequestItems: {
                    [this.tableName]: names.map(name => ({
                        PutRequest: {
                            Item: {
                                connection,
                                operation,
                                event: name,
                                subscriptionId: `${connection.id}:${operation.operationId}`,
                                connectionId: connection.id,
                                operationId: operation.operationId
                            }
                        }
                    }))
                }
            })
                .promise();
        };
        this.unsubscribe = async (subscriber) => {
            await this.db
                .delete({
                TableName: this.tableName,
                Key: {
                    event: subscriber.event,
                    subscriptionId: `${subscriber.connection.id}:${subscriber.operationId}`
                }
            })
                .promise();
        };
        this.tableName = subscriptionsTableName;
        this.db = new aws_sdk_1.DynamoDB.DocumentClient();
    }
}
exports.DynamoDBSubscriptionManager = DynamoDBSubscriptionManager;
exports.default = DynamoDBSubscriptionManager;
