"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const errors_1 = require("../errors");
class MalformedOperationError extends errors_1.ExtendableError {
    constructor(reason) {
        super(reason ? `Malformed operation: ${reason}` : 'Malformed operation');
    }
}
exports.MalformedOperationError = MalformedOperationError;
class InvalidOperationError extends errors_1.ExtendableError {
    constructor(reason) {
        super(reason ? `Invalid operation: ${reason}` : 'Invalid operation');
    }
}
exports.InvalidOperationError = InvalidOperationError;
function parseOperationFromEvent(event) {
    const operation = JSON.parse(event.body);
    if (typeof operation !== 'object' && operation !== null) {
        throw new MalformedOperationError();
    }
    if (operation.type == null) {
        throw new MalformedOperationError('Type is missing');
    }
    if (operation.type !== 'GQL_OP') {
        throw new InvalidOperationError('Only GQL_OP operations are accepted');
    }
    if (operation.id == null) {
        throw new MalformedOperationError('Property id is missing');
    }
    if (operation.payload == null) {
        throw new MalformedOperationError('Property payload is missing');
    }
    const payloadType = typeof operation.payload;
    if (payloadType !== 'object') {
        throw new MalformedOperationError('Invalid paylaod property, object expected');
    }
    return Object.assign({}, operation.payload, { operationId: operation.id });
}
exports.parseOperationFromEvent = parseOperationFromEvent;
